@@ -4,8 +4,11 @@ library(knitr)
 knitr::opts_chunk$set(
     fig.width = 1.62*4,
     fig.height = 4
-)
-
+    )
+## setup up fast sampling when run on CRAN
+if (!identical(Sys.getenv("NOT_CRAN"), "true")) {
+    options(RBesT.MC.warmup=250, RBesT.MC.iter=500, RBesT.MC.chains=2)
+}
 
 ## ----results="asis",echo=FALSE-------------------------------------------
 kable(AS)
