@@ -8,6 +8,10 @@ knitr::opts_chunk$set(
     fig.width = 7,
     fig.height = 4
 )
+## setup up fast sampling when run on CRAN
+if (!identical(Sys.getenv("NOT_CRAN"), "true")) {
+    options(RBesT.MC.warmup=250, RBesT.MC.iter=500, RBesT.MC.chains=2)
+}
 
 
 ## ----cache=TRUE,echo=FALSE,include=FALSE,message=FALSE-------------------
